@@ -31,18 +31,17 @@ var errAuthenticateNotSupported = errors.New("authenticate is not supported")
 
 func New(o *Options) (ExecCredentialPlugin, error) {
 	klog.V(10).Info(o.ToString())
-
 	// Initialize PoP token cache in Options if enabled
 	if o.IsPoPTokenEnabled && o.popTokenCache == nil {
 		// Create PoP token cache using the official MSAL & MSAL extension libraries.
 		popTokenCache, err := popcache.NewCache(o.AuthRecordCacheDir)
 		if err != nil {
 			// Fallback: Log warning and continue without PoP token caching when cache creation fails
-			klog.V(2).Infof("PoP token caching disabled due to secure storage failure (likely container environment): %v", err)
-			popTokenCache = nil
-			// Continue execution without using cached PoP tokens
+			// Leave popTokenCache unset (nil field) so GetPoPTokenCache() returns an untyped nil interface.
+			klog.Warningf("PoP token caching disabled due to secure storage failure (likely container environment): %v", err)
+		} else {
+			o.setPoPTokenCache(popTokenCache)
 		}
-		o.setPoPTokenCache(popTokenCache)
 	}
 
 	return &execCredentialPlugin{
